import 'dart:async';
import 'dart:io';
import 'package:meta/meta.dart';


/// Manejador simple de un archivo de texto:
/// Requiere la ubicación del archivo ([pathDelArchivo]) para luego
/// leer su [contenidoDelArchivo].
/// ```dart
/// String path = '${Directory.current.path.toString()}' +
/// 'ejemplo_contenido_archivo_de_texto.txt';
///
///   ArchivoDeTexto leyendo = ArchivoDeTexto(path: path);
///   await leyendo.leerContenidoSincronicamente();
///   print(leyendo.obtenerContenido());
/// ```
///
class ArchivoDeTexto {
  String pathDelArchivo;
  String contenidoDelArchivo;

  /// El constructor debe recibir obligatoriamente el [path] del archivo
  /// que se desea abrir.
  /// Luego el [path] será el [pathDelArchivo]
  ArchivoDeTexto({ @required String path}) {
    setearPathDelArchivo(path: path);
  }

  /// Lectura del contenido del archivo de forma sincrónica (interrupción de E/S)
  /// Guarda el cotenido en [contenidoDelArchivo] como una [String]
  void leerContenidoSincronicamente() async {
    var archivo = File(pathDelArchivo);
    contenidoDelArchivo = await archivo.readAsString();

  }

  /// Getter del [contenidoDelArchivo]
  String obtenerContenido() {
    return contenidoDelArchivo;
  }

  /// Setter del [pathDelArchivo]
  void setearPathDelArchivo({ @required String path}) {
    pathDelArchivo = path;
  }
}
